summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:49 -0600
commitf8069e2ea048f2657cc417d83820576ec55c181b (patch)
treecbc5bf540866934a91e0f33b260fc7a25e191fad /umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h
parente6aaa3624cc6179b82a9bfff1760e742a669064c (diff)
downloadtdesdk-f8069e2ea048f2657cc417d83820576ec55c181b.tar.gz
tdesdk-f8069e2ea048f2657cc417d83820576ec55c181b.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h')
-rw-r--r--umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h b/umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h
index afbc26b4..f9f35894 100644
--- a/umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h
+++ b/umbrello/umbrello/codegenerators/rubycodegenerationpolicy.h
@@ -24,7 +24,7 @@
#include "codegenpolicyext.h"
#include "../codegenerationpolicy.h"
-class KConfig;
+class TDEConfig;
class CodeGenerationPolicyPage;
class RubyCodeGenerationPolicy : public CodeGenPolicyExt
@@ -42,7 +42,7 @@ public:
/**
* Constructors
*/
- RubyCodeGenerationPolicy (KConfig * config = 0);
+ RubyCodeGenerationPolicy (TDEConfig * config = 0);
/**
* Empty Destructor
@@ -86,14 +86,14 @@ public:
virtual void setDefaults (CodeGenPolicyExt * defaults, bool emitUpdateSignal = true);
/**
* set the defaults from a config file for this code generator from the passed KConfig pointer.
*/
- virtual void setDefaults(KConfig * config, bool emitUpdateSignal = true);
+ virtual void setDefaults(TDEConfig * config, bool emitUpdateSignal = true);
/**
* write Default params to passed KConfig pointer.
*/
- virtual void writeConfig (KConfig * config);
+ virtual void writeConfig (TDEConfig * config);
/**
* Create a new dialog interface for this object.
@@ -86,14 +86,14 @@ public:
virtual void setDefaults (CodeGenPolicyExt * defaults, bool emitUpdateSignal = true);
/**
- * set the defaults from a config file for this code generator from the passed KConfig pointer.
+ * set the defaults from a config file for this code generator from the passed TDEConfig pointer.
*/
@@ -86,14 +86,14 @@ public:
/**
- * write Default params to passed KConfig pointer.
+ * write Default params to passed TDEConfig pointer.
*/